@@ -17,9 +17,24 @@
 # 外呼失败。
 FAILEDOPERATION_CALLOUTFAILED = 'FailedOperation.CallOutFailed'
 
+# 被叫号码外呼受限。
+FAILEDOPERATION_CALLEEISLIMITED = 'FailedOperation.CalleeIsLimited'
+
+# 主叫号码外呼超频。
+FAILEDOPERATION_CALLEROVERFREQUENCY = 'FailedOperation.CallerOverFrequency'
+
 # 重复账号。
 FAILEDOPERATION_DUPLICATEDACCOUNT = 'FailedOperation.DuplicatedAccount'
 
+# 无可用的外呼号码。
+FAILEDOPERATION_NOCALLOUTNUMBER = 'FailedOperation.NoCallOutNumber'
+
+# 权限不足。
+FAILEDOPERATION_PERMISSIONDENIED = 'FailedOperation.PermissionDenied'
+
+# 坐席处于忙碌状态。
+FAILEDOPERATION_SEATSTATUSBUSY = 'FailedOperation.SeatStatusBusy'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -41,9 +56,18 @@ INVALIDPARAMETERVALUE_ACCOUNTNOTEXIST = 'InvalidParameterValue.AccountNotExist'
 # 实例不存在。
 INVALIDPARAMETERVALUE_INSTANCENOTEXIST = 'InvalidParameterValue.InstanceNotExist'
 
+# 号码已经绑定别的账号。
+INVALIDPARAMETERVALUE_PHONENUMISBOUNDOTHERACCOUNT = 'InvalidParameterValue.PhoneNumIsBoundOtherAccount'
+
 # 查询记录不存在。
 INVALIDPARAMETERVALUE_RECORDNOTEXIST = 'InvalidParameterValue.RecordNotExist'
 
+# 技能组错误。
+INVALIDPARAMETERVALUE_SKILLGROUPERROR = 'InvalidParameterValue.SkillGroupError'
+
+# 技能组已存在。
+INVALIDPARAMETERVALUE_SKILLGROUPEXIST = 'InvalidParameterValue.SkillGroupExist'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -55,3 +79,6 @@ OPERATIONDENIED_NOTINWHITELIST = 'OperationDenied.NotInWhiteList'
 
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
